@@ -51,7 +51,7 @@ static double my_rand(void) {
 
 #define Inc 2048
 
-Boolean SuppressErrorMessages = false;
+Boolean SuppressErrorMessages = binfalse;
 #define XError(a, b, c)                                                        \
   if (!SuppressErrorMessages)                                                  \
   Error(a, b, c)
@@ -73,7 +73,7 @@ void GetData(FILE *Df, Boolean Train, Boolean AllowUnknownTarget)
 {
   CaseNo CaseSpace, i;
   DataRec DVec;
-  Boolean AnyUnknown = false, FirstIgnore = true, *AttMsg;
+  Boolean AnyUnknown = binfalse, FirstIgnore = bintrue, *AttMsg;
   Attribute Att;
   ContValue Val, Range;
   size_t size = 20;
@@ -156,7 +156,7 @@ void GetData(FILE *Df, Boolean Train, Boolean AllowUnknownTarget)
       if (FirstIgnore && Of) {
         fprintf(Of,
                 (AllowUnknownTarget ? T_IgnoreNATarget : T_IgnoreBadTarget));
-        FirstIgnore = false;
+        FirstIgnore = binfalse;
       }
 
       FreeLastCase(DVec);
@@ -299,7 +299,7 @@ Boolean ReplaceUnknowns(DataRec Case, Boolean *AttMsg)
 /*      ---------------  */
 {
   Attribute Att;
-  Boolean Replaced = false;
+  Boolean Replaced = binfalse;
 
   ForEach(Att, 1, MaxAtt) {
     if (Skip(Att) || Att == ClassAtt)
@@ -308,11 +308,11 @@ Boolean ReplaceUnknowns(DataRec Case, Boolean *AttMsg)
     if (Discrete(Att) && !DVal(Case, Att)) {
       DVal(Case, Att) = Modal[Att];
       if (AttMsg)
-        AttMsg[Att] = Replaced = true;
+        AttMsg[Att] = Replaced = bintrue;
     } else if (Continuous(Att) && CVal(Case, Att) == UNKNOWN) {
       CVal(Case, Att) = AttMean[Att];
       if (AttMsg)
-        AttMsg[Att] = Replaced = true;
+        AttMsg[Att] = Replaced = bintrue;
     }
   }
 
@@ -342,7 +342,7 @@ DataRec GetDataRec(FILE *Df, Boolean Train)
   int Dv, Chars;
   ContValue Cv;
   DataRec DVec;
-  Boolean FirstValue = true;
+  Boolean FirstValue = bintrue;
 
   if (ReadName(Df, Name, 1000, '\00')) {
     Case[MaxCase] = DVec = NewCase();
@@ -362,7 +362,7 @@ DataRec GetDataRec(FILE *Df, Boolean Train)
         FreeLastCase(DVec);
         return Nil;
       }
-      FirstValue = false;
+      FirstValue = binfalse;
 
       if (Exclude(Att)) {
         if (Att == LabelAtt) {
@@ -472,7 +472,7 @@ CaseNo CountData(FILE *Df)
   char Last = ',';
   int Count = 0, Next;
 
-  while (true) {
+  while (bintrue) {
     if ((Next = getc(Df)) == EOF) {
       if (Last != ',')
         Count++;
