@@ -278,7 +278,7 @@ void ResetKR(int KRInit)
 void Error(int ErrNo, String S1, String S2)
 /*   -----  */
 {
-  Boolean Quit = false, WarningOnly = false;
+  Boolean Quit = binfalse, WarningOnly = binfalse;
   size_t size = 10000;
   char Buffer[size];
   char *Msg = Buffer;
@@ -296,7 +296,7 @@ void Error(int ErrNo, String S1, String S2)
   switch (ErrNo) {
   case NOFILE:
     snprintf(Msg, size, E_NOFILE(Fn, S2));
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case BADATTNAME:
@@ -329,32 +329,32 @@ void Error(int ErrNo, String S1, String S2)
 
   case NOMEM:
     snprintf(Msg, size, E_NOMEM);
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case TOOMANYVALS:
     snprintf(Msg, size, E_TOOMANYVALS(S1, (int)(intptr_t)S2));
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case BADDISCRETE:
     snprintf(Msg, size, E_BADDISCRETE, S1);
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case NOTARGET:
     snprintf(Msg, size, E_NOTARGET, S1);
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case BADTARGET:
     snprintf(Msg, size, E_BADTARGET, S1);
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case LONGNAME:
     snprintf(Msg, size, E_LONGNAME);
-    Quit = true;
+    Quit = bintrue;
     break;
 
   case HITEOF:
@@ -391,7 +391,7 @@ void Error(int ErrNo, String S1, String S2)
 
   case SAMEATT:
     snprintf(Msg, size, E_SAMEATT(AttName[MaxAtt], S1));
-    WarningOnly = true;
+    WarningOnly = bintrue;
     break;
 
   case BADDEF3:
@@ -400,13 +400,13 @@ void Error(int ErrNo, String S1, String S2)
 
   case BADDEF4:
     snprintf(Msg, size, E_BADDEF4, AttName[MaxAtt]);
-    WarningOnly = true;
+    WarningOnly = bintrue;
     break;
 
   case MODELFILE:
     snprintf(Msg, size, EX_MODELFILE(Fn));
     snprintf(Msg, size, "    (%s `%s')\n", S1, S2);
-    Quit = true;
+    Quit = bintrue;
     break;
   }
 
@@ -418,7 +418,7 @@ void Error(int ErrNo, String S1, String S2)
   if (ErrMsgs == 1) {
     fprintf(Of, T_ErrorLimit);
     MaxCase--;
-    Quit = true;
+    Quit = bintrue;
   }
 
   if (Quit && Of) {
